braille library
A helper library for Text-based User Interfaces related to the Braille Unicode symbols.
Classes
- BrailleBaseCanvas
- The base class of a Braille Characters Canvas.
- BrailleCharacter
- The base class of a singular Braille character.
A helper library for Text-based User Interfaces related to the Braille Unicode symbols.