BrailleCharacter class

The base class of a singular Braille character.

Provides the low-level tools like fill, clear, invert, and other bits and dots controlling functions.

Constructors

BrailleCharacter({bool emptyIsSpace = true})
The constructor of the BrailleCharacter object.

Properties

emptyIsSpace bool
In unicode, \u2800 is a Braille empty symbol, and many text previewers view it as if it were a visible symbol. Which is why you need to turn it into a space (\u0020 or ' ').
getter/setter pair
hashCode int
The hash code for the current BrailleCharacter object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sum int
The sum of the bits of the character.
getter/setter pair
unicode int
The integer unicode getter.
no setter

Methods

bit(int X, int Y) int
Gets the integer bit from X and Y.
bitIsActive(int bit) bool
Gets the state of the given bit.
bitOff(int bit) → void
Turns off a bit.
bitOn(int bit) → void
Turns on a bit.
bitToggle(int bit) → void
Toggles a bit.
clear() → void
Clears the whole character, which clears out sum to zero.
dotIsActive(int X, int Y) bool
Gets the state of the given dot.
dotOff(int X, int Y) → void
Turns off a dot.
dotOn(int X, int Y) → void
Turns on a dot.
dotToggle(int X, int Y) → void
Toggles a dot.
fill() → void
Fills the whole character, which sets sum to 0xff (255 in decimal).
invert() → void
Inverts all bits in the character, which uses the XOR operator on sum and 0xff (255 in decimal).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of the BrailleCharacter, overriding the original toString due to the custom string logic.
override

Operators

operator ==(Object other) bool
The equal sign overrider for equality operations.
override