braille_dart library
A helper library for Text-based User Interfaces related to the Braille Unicode symbols.
Info that you might need:
- Bit: the integer representation of a dot on the symbol
Classes
- BrailleCharacter
- The base class of a singular Braille character