emptyIsSpace property
In unicode, \u2800 is a Braille empty symbol, and
many text previewers view it as if it were a visible symbol.
Which is why you need to turn it into a space (\u0020 or ' ').
Implementation
late bool emptyIsSpace;
In unicode, \u2800 is a Braille empty symbol, and
many text previewers view it as if it were a visible symbol.
Which is why you need to turn it into a space (\u0020 or ' ').
late bool emptyIsSpace;